@@ -333,8 +333,8 @@ class HklKeys:
 
 class HklFrame(BaseFrame):
     """
-    A master object which menages single-crystal diffraction files.
-    It utilises other "Hkl" classes to import, store, manipulate and output
+    A master object which manages single-crystal diffraction files.
+    It utilises other `Hkl*` classes to import, store, manipulate and output
     information about single-crystal diffraction patterns.
 
     HklFrame acts as an container which stores
@@ -873,6 +873,7 @@ class HklFrame(BaseFrame):
     def trim(self, limit):
         """
         Remove reflections further than *limit* from reciprocal space origin.
+
         :param limit: Radius of the trimming sphere in reciprocal Angstrom
         :type limit: float
         """
@@ -1194,9 +1195,6 @@ class HklWriter(HklIo):
             hkl_file.write(self._format_dict['suffix'])
 
 
-# TODO get all fixed files to templates
-
-
 class HklToResConverter:
     """A class responsible for representing hkl data using using .res format"""
 
@@ -1283,6 +1281,5 @@ class HklToResConverter:
         with open(make_abspath(path, '../hkl.msd'), 'w') as style:
             style.write(hkl_mercury_style)
 
-
     # TODO wrap table/data in getter/setter and make it automatically place,
     # TODO refresh, set keys etc.
