@@ -32,5 +32,5 @@ hkl_formats = _load_json('hkl_formats_defined.json')
 hkl_aliases = _load_json('hkl_formats_aliases.json')
 hkl_mercury_style = get(__name__, 'hkl.msd').decode('utf-8')
 characteristic_radiation = _load_json('characteristic_radiation.json')
-nacl_hkl = get(__name__, 'NaCl.hkl').decode('utf-8')
+cif_core_dict = get(__name__, 'cif_core_2.4.5.dic').decode('utf-8')
 Xray_atomic_form_factors = _load_indexed_csv('Xray_atomic_form_factors.csv')
