@@ -15,5 +15,6 @@ Users are cordially invited to propose their own scripts or script ideas.
 from .hkl_potency import potency_map, potency_vs_dac_opening_angle, \
     potency_violin_plot, dac_potency_around_axis
 from .hkl_completeness import completeness_statistics, dac_statistics, \
-    simulate_dac
+    simulate_dac, reformat_hkl
+from .compare_adps import calculate_similarity_indices
 from .r1_map import r1_map
